# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/course/entry_problem.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.atlas import testing_feedback_pb2 as eolymp_dot_atlas_dot_testing__feedback__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!eolymp/course/entry_problem.proto\x12\reolymp.course\x1a#eolymp/atlas/testing_feedback.proto\"\x96\x01\n\x07Problem\x12\x13\n\x0bproblem_url\x18\x01 \x01(\t\x12\x12\n\nproblem_id\x18\x02 \x01(\t\x12\x0c\n\x04\x63ost\x18\n \x01(\r\x12\x14\n\x0csubmit_limit\x18\x14 \x01(\r\x12>\n\x18override_feedback_policy\x18\x15 \x01(\x0e\x32\x1c.eolymp.atlas.FeedbackPolicyB/Z-github.com/eolymp/go-sdk/eolymp/course;courseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.course.entry_problem_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/course;course'
  _PROBLEM._serialized_start=90
  _PROBLEM._serialized_end=240
# @@protoc_insertion_point(module_scope)
