# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/asset/asset_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n eolymp/asset/asset_service.proto\x12\x0c\x65olymp.asset\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\"\xc2\x02\n\x10UploadImageInput\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x31\n\x04\x63rop\x18\n \x01(\x0b\x32#.eolymp.asset.UploadImageInput.Crop\x12\x31\n\x04size\x18\x0b \x01(\x0b\x32#.eolymp.asset.UploadImageInput.Size\x12\x35\n\x08variants\x18\x14 \x03(\x0b\x32#.eolymp.asset.UploadImageInput.Size\x12\x0c\n\x04\x64\x61ta\x18\x64 \x01(\x0c\x1a%\n\x04Size\x12\r\n\x05width\x18\x01 \x01(\r\x12\x0e\n\x06height\x18\x02 \x01(\r\x1a@\n\x04\x43rop\x12\x0b\n\x03top\x18\x01 \x01(\r\x12\r\n\x05right\x18\x02 \x01(\r\x12\x0e\n\x06\x62ottom\x18\x03 \x01(\r\x12\x0c\n\x04left\x18\x04 \x01(\r\"&\n\x11UploadImageOutput\x12\x11\n\timage_url\x18\x01 \x01(\t\";\n\x0fUploadFileInput\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x64 \x01(\x0c\"$\n\x10UploadFileOutput\x12\x10\n\x08\x66ile_url\x18\x01 \x01(\t\"<\n\x10UploadAssetInput\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x64 \x01(\x0c\"&\n\x11UploadAssetOutput\x12\x11\n\tasset_url\x18\x01 \x01(\t\"7\n\x19StartMultipartUploadInput\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\"/\n\x1aStartMultipartUploadOutput\x12\x11\n\tupload_id\x18\x01 \x01(\t\"G\n\x0fUploadPartInput\x12\x11\n\tupload_id\x18\x01 \x01(\t\x12\x13\n\x0bpart_number\x18\x02 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x64 \x01(\x0c\"!\n\x10UploadPartOutput\x12\r\n\x05token\x18\x01 \x01(\t\"\xde\x01\n\x1c\x43ompleteMultipartUploadInput\x12\x11\n\tupload_id\x18\x01 \x01(\t\x12>\n\x05parts\x18\n \x03(\x0b\x32/.eolymp.asset.CompleteMultipartUploadInput.Part\x1ak\n\x04Part\x12\x0e\n\x06number\x18\x01 \x01(\r\x12\r\n\x05token\x18\x02 \x01(\t\x12\x14\n\x0c\x63hecksum_md5\x18\n \x01(\t\x12\x15\n\rchecksum_sha1\x18\x0b \x01(\t\x12\x17\n\x0f\x63hecksum_sha256\x18\x0c \x01(\t\"2\n\x1d\x43ompleteMultipartUploadOutput\x12\x11\n\tasset_url\x18\x01 \x01(\t2\xab\x07\n\x0c\x41ssetService\x12\x8e\x01\n\x0bUploadImage\x12\x1e.eolymp.asset.UploadImageInput\x1a\x1f.eolymp.asset.UploadImageOutput\">\x82\xe3\n\x15\x8a\xe3\n\x11\x61sset:image:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x10\"\x0e/assets/images\x12\x8a\x01\n\nUploadFile\x12\x1d.eolymp.asset.UploadFileInput\x1a\x1e.eolymp.asset.UploadFileOutput\"=\x82\xe3\n\x15\x8a\xe3\n\x11\x61sset:image:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x0f\"\r/assets/files\x12\x87\x01\n\x0bUploadAsset\x12\x1e.eolymp.asset.UploadAssetInput\x1a\x1f.eolymp.asset.UploadAssetOutput\"7\x82\xe3\n\x15\x8a\xe3\n\x11\x61sset:asset:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\nd\x82\xd3\xe4\x93\x02\t\"\x07/assets\x12\xa3\x01\n\x14StartMultipartUpload\x12\'.eolymp.asset.StartMultipartUploadInput\x1a(.eolymp.asset.StartMultipartUploadOutput\"8\x82\xe3\n\x15\x8a\xe3\n\x11\x61tlas:asset:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02\n\x1a\x08/uploads\x12\x91\x01\n\nUploadPart\x12\x1d.eolymp.asset.UploadPartInput\x1a\x1e.eolymp.asset.UploadPartOutput\"D\x82\xe3\n\x15\x8a\xe3\n\x11\x61tlas:asset:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x16\"\x14/uploads/{upload_id}\x12\xb8\x01\n\x17\x43ompleteMultipartUpload\x12*.eolymp.asset.CompleteMultipartUploadInput\x1a+.eolymp.asset.CompleteMultipartUploadOutput\"D\x82\xe3\n\x15\x8a\xe3\n\x11\x61tlas:asset:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x16\x1a\x14/uploads/{upload_id}B-Z+github.com/eolymp/go-sdk/eolymp/asset;assetb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.asset.asset_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/asset;asset'
  _ASSETSERVICE.methods_by_name['UploadImage']._options = None
  _ASSETSERVICE.methods_by_name['UploadImage']._serialized_options = b'\202\343\n\025\212\343\n\021asset:image:write\352\342\n\013\365\342\n\000\000\000@\370\342\nd\202\323\344\223\002\020\"\016/assets/images'
  _ASSETSERVICE.methods_by_name['UploadFile']._options = None
  _ASSETSERVICE.methods_by_name['UploadFile']._serialized_options = b'\202\343\n\025\212\343\n\021asset:image:write\352\342\n\013\365\342\n\000\000\000@\370\342\nd\202\323\344\223\002\017\"\r/assets/files'
  _ASSETSERVICE.methods_by_name['UploadAsset']._options = None
  _ASSETSERVICE.methods_by_name['UploadAsset']._serialized_options = b'\202\343\n\025\212\343\n\021asset:asset:write\352\342\n\013\365\342\n\000\000\000@\370\342\nd\202\323\344\223\002\t\"\007/assets'
  _ASSETSERVICE.methods_by_name['StartMultipartUpload']._options = None
  _ASSETSERVICE.methods_by_name['StartMultipartUpload']._serialized_options = b'\202\343\n\025\212\343\n\021atlas:asset:write\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\002\n\032\010/uploads'
  _ASSETSERVICE.methods_by_name['UploadPart']._options = None
  _ASSETSERVICE.methods_by_name['UploadPart']._serialized_options = b'\202\343\n\025\212\343\n\021atlas:asset:write\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\002\026\"\024/uploads/{upload_id}'
  _ASSETSERVICE.methods_by_name['CompleteMultipartUpload']._options = None
  _ASSETSERVICE.methods_by_name['CompleteMultipartUpload']._serialized_options = b'\202\343\n\025\212\343\n\021atlas:asset:write\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\002\026\032\024/uploads/{upload_id}'
  _UPLOADIMAGEINPUT._serialized_start=150
  _UPLOADIMAGEINPUT._serialized_end=472
  _UPLOADIMAGEINPUT_SIZE._serialized_start=369
  _UPLOADIMAGEINPUT_SIZE._serialized_end=406
  _UPLOADIMAGEINPUT_CROP._serialized_start=408
  _UPLOADIMAGEINPUT_CROP._serialized_end=472
  _UPLOADIMAGEOUTPUT._serialized_start=474
  _UPLOADIMAGEOUTPUT._serialized_end=512
  _UPLOADFILEINPUT._serialized_start=514
  _UPLOADFILEINPUT._serialized_end=573
  _UPLOADFILEOUTPUT._serialized_start=575
  _UPLOADFILEOUTPUT._serialized_end=611
  _UPLOADASSETINPUT._serialized_start=613
  _UPLOADASSETINPUT._serialized_end=673
  _UPLOADASSETOUTPUT._serialized_start=675
  _UPLOADASSETOUTPUT._serialized_end=713
  _STARTMULTIPARTUPLOADINPUT._serialized_start=715
  _STARTMULTIPARTUPLOADINPUT._serialized_end=770
  _STARTMULTIPARTUPLOADOUTPUT._serialized_start=772
  _STARTMULTIPARTUPLOADOUTPUT._serialized_end=819
  _UPLOADPARTINPUT._serialized_start=821
  _UPLOADPARTINPUT._serialized_end=892
  _UPLOADPARTOUTPUT._serialized_start=894
  _UPLOADPARTOUTPUT._serialized_end=927
  _COMPLETEMULTIPARTUPLOADINPUT._serialized_start=930
  _COMPLETEMULTIPARTUPLOADINPUT._serialized_end=1152
  _COMPLETEMULTIPARTUPLOADINPUT_PART._serialized_start=1045
  _COMPLETEMULTIPARTUPLOADINPUT_PART._serialized_end=1152
  _COMPLETEMULTIPARTUPLOADOUTPUT._serialized_start=1154
  _COMPLETEMULTIPARTUPLOADOUTPUT._serialized_end=1204
  _ASSETSERVICE._serialized_start=1207
  _ASSETSERVICE._serialized_end=2146
# @@protoc_insertion_point(module_scope)
