# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/judge/contest.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x65olymp/judge/contest.proto\x12\x0c\x65olymp.judge\x1a\x1fgoogle/protobuf/timestamp.proto\"\xd1\x0f\n\x07\x43ontest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x30\n\x05links\x18\xab\x05 \x03(\x0b\x32 .eolymp.judge.Contest.LinksEntry\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x10\n\x08logo_url\x18\x04 \x01(\t\x12-\n\tstarts_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\tstarts_in\x18\x0b \x01(\r\x12+\n\x07\x65nds_at\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07\x65nds_in\x18\x10 \x01(\r\x12\x10\n\x08\x64uration\x18\x0c \x01(\r\x12,\n\x06status\x18\x14 \x01(\x0e\x32\x1c.eolymp.judge.Contest.Status\x12\x34\n\nvisibility\x18\x1e \x01(\x0e\x32 .eolymp.judge.Contest.Visibility\x12\x19\n\x11join_unofficially\x18! \x01(\x08\x12\x43\n\x12participation_mode\x18\x1f \x01(\x0e\x32\'.eolymp.judge.Contest.ParticipationMode\x12,\n\x06\x66ormat\x18  \x01(\x0e\x32\x1c.eolymp.judge.Contest.Format\x12\x0b\n\x03key\x18( \x01(\t\x12\x15\n\rproblem_count\x18< \x01(\r\x12\x1c\n\x14problem_count_hidden\x18= \x01(\x08\x12\x19\n\x11participant_count\x18> \x01(\r\x12 \n\x18participant_count_hidden\x18? \x01(\x08\x12\x32\n\x0e\x66\x65\x61tured_until\x18\x32 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x08taxonomy\x18h \x01(\x0b\x32\x1e.eolymp.judge.Contest.Taxonomy\x12\x34\n\nappearance\x18\x65 \x01(\x0b\x32 .eolymp.judge.Contest.Appearance\x12\x36\n\x0b\x65nvironment\x18g \x01(\x0b\x32!.eolymp.judge.Contest.Environment\x12.\n\x07upsolve\x18\x66 \x01(\x0b\x32\x1d.eolymp.judge.Contest.Upsolve\x12\x34\n\nscoreboard\x18i \x01(\x0b\x32 .eolymp.judge.Contest.Scoreboard\x1a\x42\n\nAppearance\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12\x10\n\x08logo_url\x18\x03 \x01(\t\x1a\xf6\x01\n\x08Taxonomy\x12\x0c\n\x04year\x18\x01 \x01(\r\x12\x0e\n\x06series\x18\x02 \x01(\t\x12\x33\n\x05scale\x18\x03 \x01(\x0e\x32$.eolymp.judge.Contest.Taxonomy.Scale\x12\x12\n\ndifficulty\x18\x04 \x01(\r\x12\x0f\n\x07\x63ountry\x18\x05 \x01(\t\x12\x0e\n\x06region\x18\x06 \x01(\t\x12\x0c\n\x04\x63ity\x18\x07 \x01(\t\"T\n\x05Scale\x12\x11\n\rUNKNOWN_SCALE\x10\x00\x12\t\n\x05LOCAL\x10\x01\x12\x0c\n\x08REGIONAL\x10\x02\x12\x0c\n\x08NATIONAL\x10\x03\x12\x11\n\rINTERNATIONAL\x10\x04\x1a\'\n\x0b\x45nvironment\x12\x18\n\x10\x61llowed_runtimes\x18\x01 \x03(\t\x1a\x38\n\x07Upsolve\x12\x14\n\x0c\x66ree_upsolve\x18\x03 \x01(\x08\x12\x17\n\x0fvirtual_upsolve\x18\x04 \x01(\x08\x1a\xa3\x02\n\nScoreboard\x12?\n\nvisibility\x18\x01 \x01(\x0e\x32+.eolymp.judge.Contest.Scoreboard.Visibility\x12\x15\n\rfreezing_time\x18\x02 \x01(\r\x12\x16\n\x0eunfreeze_delay\x18\x03 \x01(\x05\x12\x17\n\x0f\x61ttempt_penalty\x18\x04 \x01(\r\x12\x13\n\x0btie_breaker\x18\x05 \x01(\t\x12\x15\n\rno_spoiler_ui\x18\x06 \x01(\x08\x12\x11\n\tshare_key\x18\x07 \x01(\t\"M\n\nVisibility\x12\x16\n\x12UNKNOWN_VISIBILITY\x10\x00\x12\r\n\tINVISIBLE\x10\x01\x12\x0c\n\x08INTERNAL\x10\x02\x12\n\n\x06PUBLIC\x10\x03\x1a,\n\nLinksEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"^\n\x06Status\x12\x12\n\x0eSTATUS_UNKNOWN\x10\x00\x12\r\n\tSCHEDULED\x10\x01\x12\x08\n\x04OPEN\x10\x02\x12\x0c\n\x08\x43OMPLETE\x10\x03\x12\r\n\tSUSPENDED\x10\x04\x12\n\n\x06\x46ROZEN\x10\x05\"K\n\nVisibility\x12\x16\n\x12VISIBILITY_UNKNOWN\x10\x00\x12\n\n\x06PUBLIC\x10\x01\x12\x0c\n\x08UNLISTED\x10\x02\x12\x0b\n\x07PRIVATE\x10\x03\"L\n\x11ParticipationMode\x12\x1e\n\x1aPARTICIPATION_MODE_UNKNOWN\x10\x00\x12\n\n\x06ONLINE\x10\x01\x12\x0b\n\x07VIRTUAL\x10\x02\"/\n\x06\x46ormat\x12\x12\n\x0e\x46ORMAT_UNKNOWN\x10\x00\x12\x07\n\x03IOI\x10\x01\x12\x08\n\x04ICPC\x10\x02\x42-Z+github.com/eolymp/go-sdk/eolymp/judge;judgeb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.contest_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/judge;judge'
  _CONTEST_LINKSENTRY._options = None
  _CONTEST_LINKSENTRY._serialized_options = b'8\001'
  _CONTEST._serialized_start=78
  _CONTEST._serialized_end=2079
  _CONTEST_APPEARANCE._serialized_start=1025
  _CONTEST_APPEARANCE._serialized_end=1091
  _CONTEST_TAXONOMY._serialized_start=1094
  _CONTEST_TAXONOMY._serialized_end=1340
  _CONTEST_TAXONOMY_SCALE._serialized_start=1256
  _CONTEST_TAXONOMY_SCALE._serialized_end=1340
  _CONTEST_ENVIRONMENT._serialized_start=1342
  _CONTEST_ENVIRONMENT._serialized_end=1381
  _CONTEST_UPSOLVE._serialized_start=1383
  _CONTEST_UPSOLVE._serialized_end=1439
  _CONTEST_SCOREBOARD._serialized_start=1442
  _CONTEST_SCOREBOARD._serialized_end=1733
  _CONTEST_SCOREBOARD_VISIBILITY._serialized_start=1656
  _CONTEST_SCOREBOARD_VISIBILITY._serialized_end=1733
  _CONTEST_LINKSENTRY._serialized_start=1735
  _CONTEST_LINKSENTRY._serialized_end=1779
  _CONTEST_STATUS._serialized_start=1781
  _CONTEST_STATUS._serialized_end=1875
  _CONTEST_VISIBILITY._serialized_start=1877
  _CONTEST_VISIBILITY._serialized_end=1952
  _CONTEST_PARTICIPATIONMODE._serialized_start=1954
  _CONTEST_PARTICIPATIONMODE._serialized_end=2030
  _CONTEST_FORMAT._serialized_start=2032
  _CONTEST_FORMAT._serialized_end=2079
# @@protoc_insertion_point(module_scope)
