# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/atlas/submission.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.atlas import testing_feedback_pb2 as eolymp_dot_atlas_dot_testing__feedback__pb2
from eolymp.atlas import testing_scoring_pb2 as eolymp_dot_atlas_dot_testing__scoring__pb2
from eolymp.executor import stats_pb2 as eolymp_dot_executor_dot_stats__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x65olymp/atlas/submission.proto\x12\x0c\x65olymp.atlas\x1a#eolymp/atlas/testing_feedback.proto\x1a\"eolymp/atlas/testing_scoring.proto\x1a\x1b\x65olymp/executor/stats.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xe8\x13\n\nSubmission\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nproblem_id\x18\x02 \x01(\t\x12\x0f\n\x07user_id\x18\x03 \x01(\t\x12\x11\n\tmember_id\x18\x04 \x01(\t\x12\x30\n\x0csubmitted_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04lang\x18\n \x01(\t\x12\x0e\n\x06source\x18\x0b \x01(\t\x12\x12\n\nsource_url\x18\r \x01(\t\x12\x11\n\tsignature\x18\x0c \x01(\t\x12/\n\x06status\x18\x14 \x01(\x0e\x32\x1f.eolymp.atlas.Submission.Status\x12\x31\n\x07verdict\x18\x16 \x01(\x0e\x32 .eolymp.atlas.Submission.Verdict\x12\r\n\x05\x65rror\x18\x15 \x01(\t\x12\x11\n\terror_url\x18\x17 \x01(\t\x12\x0c\n\x04\x63ost\x18\x1e \x01(\x02\x12\r\n\x05score\x18\x1f \x01(\x02\x12\x12\n\npercentage\x18  \x01(\x02\x12\x17\n\x0fwall_time_usage\x18) \x01(\r\x12\x16\n\x0e\x63pu_time_usage\x18* \x01(\r\x12\x14\n\x0cmemory_usage\x18. \x01(\x04\x12\x16\n\x0eresource_usage\x18/ \x01(\x02\x12.\n\x06groups\x18\x32 \x03(\x0b\x32\x1e.eolymp.atlas.Submission.Group\x12\x0e\n\x06\x63ursor\x18\x64 \x01(\t\x1ai\n\x14\x43heckerExecutionData\x12\x0f\n\x07log_url\x18\x01 \x01(\t\x12\x17\n\x0fwall_time_usage\x18\x02 \x01(\r\x12\x14\n\x0cmemory_usage\x18\x03 \x01(\x04\x12\x11\n\texit_code\x18\x04 \x01(\r\x1al\n\x17InteractorExecutionData\x12\x0f\n\x07log_url\x18\x01 \x01(\t\x12\x17\n\x0fwall_time_usage\x18\x02 \x01(\r\x12\x14\n\x0cmemory_usage\x18\x03 \x01(\x04\x12\x11\n\texit_code\x18\x04 \x01(\r\x1a\xde\x06\n\x03Run\x12\n\n\x02id\x18\x01 \x01(\t\x12\x17\n\x0fwall_time_usage\x18\x02 \x01(\r\x12\x16\n\x0e\x63pu_time_usage\x18\x03 \x01(\r\x12\x14\n\x0cmemory_usage\x18\x04 \x01(\x04\x12\x16\n\x0eresource_usage\x18\x05 \x01(\x02\x12\x12\n\noutput_url\x18\x06 \x01(\t\x12\x12\n\nstderr_url\x18\x07 \x01(\t\x12\r\n\x05index\x18\n \x01(\r\x12\x0f\n\x07test_id\x18\x0b \x01(\t\x12\x0c\n\x04\x63ost\x18\x0c \x01(\x02\x12\r\n\x05score\x18\r \x01(\x02\x12\x33\n\x06status\x18\x14 \x01(\x0e\x32#.eolymp.atlas.Submission.Run.Status\x12\x31\n\x07verdict\x18\x15 \x01(\x0e\x32 .eolymp.atlas.Submission.Verdict\x12%\n\x05stats\x18\x0e \x01(\x0b\x32\x16.eolymp.executor.Stats\x12M\n\x16\x63hecker_execution_data\x18\x1e \x01(\x0b\x32-.eolymp.atlas.Submission.CheckerExecutionData\x12-\n\rchecker_stats\x18\x1f \x01(\x0b\x32\x16.eolymp.executor.Stats\x12S\n\x19interactor_execution_data\x18( \x01(\x0b\x32\x30.eolymp.atlas.Submission.InteractorExecutionData\x12\x30\n\x10interactor_stats\x18) \x01(\x0b\x32\x16.eolymp.executor.Stats\"\xf2\x01\n\x06Status\x12\r\n\tNO_STATUS\x10\x00\x12\x0b\n\x07\x43REATED\x10\x01\x12\r\n\tEXECUTING\x10\x02\x12\x0c\n\x08\x43OMPLETE\x10\r\x12\x0b\n\x07SKIPPED\x10\n\x12\x0b\n\x07\x42LOCKED\x10\x0b\x12\x16\n\x12VERIFICATION_ERROR\x10\t\x12\x15\n\x11INTERACTION_ERROR\x10\x0c\x12\x0b\n\x07TIMEOUT\x10\x03\x12\x11\n\rCPU_EXHAUSTED\x10\x04\x12\x13\n\x0fMEMORY_OVERFLOW\x10\x05\x12\x10\n\x0cWRONG_ANSWER\x10\x06\x12\x0c\n\x08\x41\x43\x43\x45PTED\x10\x07\x12\x11\n\rRUNTIME_ERROR\x10\x08\x1a\x9d\x05\n\x05Group\x12\r\n\x05index\x18\x01 \x01(\r\x12\x12\n\ntestset_id\x18\x02 \x01(\t\x12\x35\n\x06status\x18\n \x01(\x0e\x32%.eolymp.atlas.Submission.Group.Status\x12\x31\n\x07verdict\x18\x0c \x01(\x0e\x32 .eolymp.atlas.Submission.Verdict\x12\x14\n\x0c\x64\x65pendencies\x18\x0b \x03(\r\x12\x0c\n\x04\x63ost\x18\x14 \x01(\x02\x12\r\n\x05score\x18\x15 \x01(\x02\x12/\n\x0cscoring_mode\x18\x16 \x01(\x0e\x32\x19.eolymp.atlas.ScoringMode\x12\x35\n\x0f\x66\x65\x65\x64\x62\x61\x63k_policy\x18\x1e \x01(\x0e\x32\x1c.eolymp.atlas.FeedbackPolicy\x12\x17\n\x0fwall_time_usage\x18) \x01(\r\x12\x16\n\x0e\x63pu_time_usage\x18* \x01(\r\x12\x14\n\x0cmemory_usage\x18. \x01(\x04\x12\x16\n\x0eresource_usage\x18/ \x01(\x02\x12*\n\x04runs\x18\x64 \x03(\x0b\x32\x1c.eolymp.atlas.Submission.Run\"\xe0\x01\n\x06Status\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07\x42LOCKED\x10\x01\x12\x0b\n\x07PENDING\x10\x02\x12\x0b\n\x07TESTING\x10\x03\x12\x0c\n\x08\x41\x43\x43\x45PTED\x10\x04\x12\x0b\n\x07TIMEOUT\x10\x05\x12\x11\n\rCPU_EXHAUSTED\x10\x06\x12\x13\n\x0fMEMORY_OVERFLOW\x10\x07\x12\x10\n\x0cWRONG_ANSWER\x10\x08\x12\x11\n\rRUNTIME_ERROR\x10\t\x12\x16\n\x12VERIFICATION_ERROR\x10\n\x12\x0b\n\x07SKIPPED\x10\x0b\x12\x15\n\x11INTERACTION_ERROR\x10\x0c\"_\n\x06Status\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x0b\n\x07TESTING\x10\x02\x12\x0b\n\x07TIMEOUT\x10\x03\x12\x0c\n\x08\x43OMPLETE\x10\x04\x12\t\n\x05\x45RROR\x10\x05\x12\x0b\n\x07\x46\x41ILURE\x10\x06\"\x8d\x01\n\x07Verdict\x12\x0e\n\nNO_VERDICT\x10\x00\x12\x0c\n\x08\x41\x43\x43\x45PTED\x10\x01\x12\x10\n\x0cWRONG_ANSWER\x10\x02\x12\x17\n\x13TIME_LIMIT_EXCEEDED\x10\x03\x12\x11\n\rCPU_EXHAUSTED\x10\x04\x12\x13\n\x0fMEMORY_OVERFLOW\x10\x05\x12\x11\n\rRUNTIME_ERROR\x10\x06\x42-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.submission_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _SUBMISSION._serialized_start=183
  _SUBMISSION._serialized_end=2719
  _SUBMISSION_CHECKEREXECUTIONDATA._serialized_start=726
  _SUBMISSION_CHECKEREXECUTIONDATA._serialized_end=831
  _SUBMISSION_INTERACTOREXECUTIONDATA._serialized_start=833
  _SUBMISSION_INTERACTOREXECUTIONDATA._serialized_end=941
  _SUBMISSION_RUN._serialized_start=944
  _SUBMISSION_RUN._serialized_end=1806
  _SUBMISSION_RUN_STATUS._serialized_start=1564
  _SUBMISSION_RUN_STATUS._serialized_end=1806
  _SUBMISSION_GROUP._serialized_start=1809
  _SUBMISSION_GROUP._serialized_end=2478
  _SUBMISSION_GROUP_STATUS._serialized_start=2254
  _SUBMISSION_GROUP_STATUS._serialized_end=2478
  _SUBMISSION_STATUS._serialized_start=2480
  _SUBMISSION_STATUS._serialized_end=2575
  _SUBMISSION_VERDICT._serialized_start=2578
  _SUBMISSION_VERDICT._serialized_end=2719
# @@protoc_insertion_point(module_scope)
