# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/helpdesk/auto_reply_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.helpdesk import auto_reply_pb2 as eolymp_dot_helpdesk_dot_auto__reply__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(eolymp/helpdesk/auto_reply_service.proto\x12\x0f\x65olymp.helpdesk\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a eolymp/helpdesk/auto_reply.proto\x1a!eolymp/wellknown/expression.proto\"A\n\x14\x43reateAutoReplyInput\x12)\n\x05reply\x18\x01 \x01(\x0b\x32\x1a.eolymp.helpdesk.AutoReply\")\n\x15\x43reateAutoReplyOutput\x12\x10\n\x08reply_id\x18\x01 \x01(\t\"S\n\x14UpdateAutoReplyInput\x12\x10\n\x08reply_id\x18\x01 \x01(\t\x12)\n\x05reply\x18\x02 \x01(\x0b\x32\x1a.eolymp.helpdesk.AutoReply\"\x17\n\x15UpdateAutoReplyOutput\"(\n\x14\x44\x65leteAutoReplyInput\x12\x10\n\x08reply_id\x18\x01 \x01(\t\"\x17\n\x15\x44\x65leteAutoReplyOutput\"\xfa\x01\n\x14ListAutoRepliesInput\x12\x0e\n\x06render\x18\x01 \x01(\x08\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12=\n\x07\x66ilters\x18( \x01(\x0b\x32,.eolymp.helpdesk.ListAutoRepliesInput.Filter\x1au\n\x06\x46ilter\x12\r\n\x05query\x18\x01 \x01(\t\x12*\n\x02id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x06locale\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"Q\n\x15ListAutoRepliesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12)\n\x05items\x18\x02 \x03(\x0b\x32\x1a.eolymp.helpdesk.AutoReply\":\n\x16\x44\x65scribeAutoReplyInput\x12\x10\n\x08reply_id\x18\x01 \x01(\t\x12\x0e\n\x06render\x18\x02 \x01(\x08\"D\n\x17\x44\x65scribeAutoReplyOutput\x12)\n\x05reply\x18\x01 \x01(\x0b\x32\x1a.eolymp.helpdesk.AutoReply2\xb7\x07\n\x10\x41utoReplyService\x12\xb0\x01\n\x0f\x43reateAutoReply\x12%.eolymp.helpdesk.CreateAutoReplyInput\x1a&.eolymp.helpdesk.CreateAutoReplyOutput\"N\x82\xe3\n\x1d\x8a\xe3\n\x19helpdesk:auto-reply:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x18\"\x16/helpdesk/auto-replies\x12\xbb\x01\n\x0fUpdateAutoReply\x12%.eolymp.helpdesk.UpdateAutoReplyInput\x1a&.eolymp.helpdesk.UpdateAutoReplyOutput\"Y\x82\xe3\n\x1d\x8a\xe3\n\x19helpdesk:auto-reply:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02#\x1a!/helpdesk/auto-replies/{reply_id}\x12\xbb\x01\n\x0f\x44\x65leteAutoReply\x12%.eolymp.helpdesk.DeleteAutoReplyInput\x1a&.eolymp.helpdesk.DeleteAutoReplyOutput\"Y\x82\xe3\n\x1d\x8a\xe3\n\x19helpdesk:auto-reply:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02#*!/helpdesk/auto-replies/{reply_id}\x12\xaf\x01\n\x0fListAutoReplies\x12%.eolymp.helpdesk.ListAutoRepliesInput\x1a&.eolymp.helpdesk.ListAutoRepliesOutput\"M\x82\xe3\n\x1c\x8a\xe3\n\x18helpdesk:auto-reply:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x18\x12\x16/helpdesk/auto-replies\x12\xc1\x01\n\x11\x44\x65scribeAutoReply\x12\'.eolymp.helpdesk.DescribeAutoReplyInput\x1a(.eolymp.helpdesk.DescribeAutoReplyOutput\"Y\x82\xe3\n\x1d\x8a\xe3\n\x19helpdesk:auto-reply:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02#\x12!/helpdesk/auto-replies/{reply_id}B3Z1github.com/eolymp/go-sdk/eolymp/helpdesk;helpdeskb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.helpdesk.auto_reply_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/helpdesk;helpdesk'
  _AUTOREPLYSERVICE.methods_by_name['CreateAutoReply']._options = None
  _AUTOREPLYSERVICE.methods_by_name['CreateAutoReply']._serialized_options = b'\202\343\n\035\212\343\n\031helpdesk:auto-reply:write\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002\030\"\026/helpdesk/auto-replies'
  _AUTOREPLYSERVICE.methods_by_name['UpdateAutoReply']._options = None
  _AUTOREPLYSERVICE.methods_by_name['UpdateAutoReply']._serialized_options = b'\202\343\n\035\212\343\n\031helpdesk:auto-reply:write\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002#\032!/helpdesk/auto-replies/{reply_id}'
  _AUTOREPLYSERVICE.methods_by_name['DeleteAutoReply']._options = None
  _AUTOREPLYSERVICE.methods_by_name['DeleteAutoReply']._serialized_options = b'\202\343\n\035\212\343\n\031helpdesk:auto-reply:write\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002#*!/helpdesk/auto-replies/{reply_id}'
  _AUTOREPLYSERVICE.methods_by_name['ListAutoReplies']._options = None
  _AUTOREPLYSERVICE.methods_by_name['ListAutoReplies']._serialized_options = b'\202\343\n\034\212\343\n\030helpdesk:auto-reply:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\030\022\026/helpdesk/auto-replies'
  _AUTOREPLYSERVICE.methods_by_name['DescribeAutoReply']._options = None
  _AUTOREPLYSERVICE.methods_by_name['DescribeAutoReply']._serialized_options = b'\202\343\n\035\212\343\n\031helpdesk:auto-reply:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002#\022!/helpdesk/auto-replies/{reply_id}'
  _CREATEAUTOREPLYINPUT._serialized_start=229
  _CREATEAUTOREPLYINPUT._serialized_end=294
  _CREATEAUTOREPLYOUTPUT._serialized_start=296
  _CREATEAUTOREPLYOUTPUT._serialized_end=337
  _UPDATEAUTOREPLYINPUT._serialized_start=339
  _UPDATEAUTOREPLYINPUT._serialized_end=422
  _UPDATEAUTOREPLYOUTPUT._serialized_start=424
  _UPDATEAUTOREPLYOUTPUT._serialized_end=447
  _DELETEAUTOREPLYINPUT._serialized_start=449
  _DELETEAUTOREPLYINPUT._serialized_end=489
  _DELETEAUTOREPLYOUTPUT._serialized_start=491
  _DELETEAUTOREPLYOUTPUT._serialized_end=514
  _LISTAUTOREPLIESINPUT._serialized_start=517
  _LISTAUTOREPLIESINPUT._serialized_end=767
  _LISTAUTOREPLIESINPUT_FILTER._serialized_start=650
  _LISTAUTOREPLIESINPUT_FILTER._serialized_end=767
  _LISTAUTOREPLIESOUTPUT._serialized_start=769
  _LISTAUTOREPLIESOUTPUT._serialized_end=850
  _DESCRIBEAUTOREPLYINPUT._serialized_start=852
  _DESCRIBEAUTOREPLYINPUT._serialized_end=910
  _DESCRIBEAUTOREPLYOUTPUT._serialized_start=912
  _DESCRIBEAUTOREPLYOUTPUT._serialized_end=980
  _AUTOREPLYSERVICE._serialized_start=983
  _AUTOREPLYSERVICE._serialized_end=1934
# @@protoc_insertion_point(module_scope)
