# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/ranker/activity.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x65olymp/ranker/activity.proto\x12\reolymp.ranker\x1a\x1fgoogle/protobuf/timestamp.proto\"\xef\x03\n\x08\x41\x63tivity\x12\n\n\x02id\x18\x01 \x01(\t\x12*\n\x04type\x18\x02 \x01(\x0e\x32\x1c.eolymp.ranker.Activity.Type\x12.\n\x06status\x18\x03 \x01(\x0e\x32\x1e.eolymp.ranker.Activity.Status\x12\x15\n\rscoreboard_id\x18\x05 \x01(\t\x12.\n\ncreated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nstarted_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0bprogress_at\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0b\x63omplete_at\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08progress\x18\x14 \x01(\r\x12\r\n\x05total\x18\x15 \x01(\r\x12\r\n\x05\x65rror\x18\x1e \x01(\t\"(\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\x16\n\x12SCOREBOARD_REBUILD\x10\x01\"H\n\x06Status\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07\x43REATED\x10\x01\x12\x0b\n\x07STARTED\x10\x02\x12\x0c\n\x08\x43OMPLETE\x10\x03\x12\t\n\x05\x45RROR\x10\x04\x42/Z-github.com/eolymp/go-sdk/eolymp/ranker;rankerb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.ranker.activity_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/ranker;ranker'
  _ACTIVITY._serialized_start=81
  _ACTIVITY._serialized_end=576
  _ACTIVITY_TYPE._serialized_start=462
  _ACTIVITY_TYPE._serialized_end=502
  _ACTIVITY_STATUS._serialized_start=504
  _ACTIVITY_STATUS._serialized_end=576
# @@protoc_insertion_point(module_scope)
