# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/keeper/keeper.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x65olymp/keeper/keeper.proto\x12\reolymp.keeper\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\"!\n\x11\x43reateObjectInput\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"S\n\x12\x43reateObjectOutput\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x10\n\x08\x62lob_ern\x18\x02 \x01(\t\x12\x11\n\tblob_hash\x18\x03 \x01(\t\x12\x0b\n\x03url\x18\x04 \x01(\t\"\"\n\x13\x44\x65scribeObjectInput\x12\x0b\n\x03key\x18\x01 \x01(\t\"$\n\x14\x44\x65scribeObjectOutput\x12\x0c\n\x04size\x18\x01 \x01(\x05\"@\n\x13\x44ownloadObjectInput\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\"2\n\x14\x44ownloadObjectOutput\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\x0c\n\x04size\x18\x02 \x01(\x05\"\x1b\n\x19StartMultipartUploadInput\"B\n\x1aStartMultipartUploadOutput\x12\x11\n\tobject_id\x18\x01 \x01(\t\x12\x11\n\tupload_id\x18\x02 \x01(\t\"Z\n\x0fUploadPartInput\x12\x11\n\tobject_id\x18\x01 \x01(\t\x12\x11\n\tupload_id\x18\x02 \x01(\t\x12\x13\n\x0bpart_number\x18\x03 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\n \x01(\x0c\" \n\x10UploadPartOutput\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\"\xc2\x01\n\x1c\x43ompleteMultipartUploadInput\x12\x11\n\tobject_id\x18\x01 \x01(\t\x12\x11\n\tupload_id\x18\x02 \x01(\t\x12?\n\x05parts\x18\n \x03(\x0b\x32\x30.eolymp.keeper.CompleteMultipartUploadInput.Part\x1a;\n\x04Part\x12\x0e\n\x06number\x18\x01 \x01(\r\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\x15\n\rchecksum_sha1\x18\n \x01(\t\"\x1f\n\x1d\x43ompleteMultipartUploadOutput2\xec\x07\n\x06Keeper\x12\x90\x01\n\x0c\x43reateObject\x12 .eolymp.keeper.CreateObjectInput\x1a!.eolymp.keeper.CreateObjectOutput\";\x82\xe3\n\x17\x8a\xe3\n\x13keeper:object:write\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\xf4\x03\x82\xd3\xe4\x93\x02\n\"\x08/objects\x12\x9b\x01\n\x0e\x44\x65scribeObject\x12\".eolymp.keeper.DescribeObjectInput\x1a#.eolymp.keeper.DescribeObjectOutput\"@\x82\xe3\n\x16\x8a\xe3\n\x12keeper:object:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HB\xf8\xe2\n\xf4\x03\x82\xd3\xe4\x93\x02\x10\x12\x0e/objects/{key}\x12\xa0\x01\n\x0e\x44ownloadObject\x12\".eolymp.keeper.DownloadObjectInput\x1a#.eolymp.keeper.DownloadObjectOutput\"E\x82\xe3\n\x16\x8a\xe3\n\x12keeper:object:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HB\xf8\xe2\n\xf4\x03\x82\xd3\xe4\x93\x02\x15\x12\x13/objects/{key}/data\x12\xa7\x01\n\x14StartMultipartUpload\x12(.eolymp.keeper.StartMultipartUploadInput\x1a).eolymp.keeper.StartMultipartUploadOutput\":\x82\xe3\n\x17\x8a\xe3\n\x13keeper:object:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02\n\"\x08/uploads\x12\x9b\x01\n\nUploadPart\x12\x1e.eolymp.keeper.UploadPartInput\x1a\x1f.eolymp.keeper.UploadPartOutput\"L\x82\xe3\n\x17\x8a\xe3\n\x13keeper:object:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x1c\"\x1a/objects/{object_id}/parts\x12\xc5\x01\n\x17\x43ompleteMultipartUpload\x12+.eolymp.keeper.CompleteMultipartUploadInput\x1a,.eolymp.keeper.CompleteMultipartUploadOutput\"O\x82\xe3\n\x17\x8a\xe3\n\x13keeper:object:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x1f\"\x1d/objects/{object_id}/completeB/Z-github.com/eolymp/go-sdk/eolymp/keeper;keeperb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.keeper.keeper_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/keeper;keeper'
  _KEEPER.methods_by_name['CreateObject']._options = None
  _KEEPER.methods_by_name['CreateObject']._serialized_options = b'\202\343\n\027\212\343\n\023keeper:object:write\352\342\n\014\365\342\n\000\000\000@\370\342\n\364\003\202\323\344\223\002\n\"\010/objects'
  _KEEPER.methods_by_name['DescribeObject']._options = None
  _KEEPER.methods_by_name['DescribeObject']._serialized_options = b'\202\343\n\026\212\343\n\022keeper:object:read\352\342\n\014\365\342\n\000\000HB\370\342\n\364\003\202\323\344\223\002\020\022\016/objects/{key}'
  _KEEPER.methods_by_name['DownloadObject']._options = None
  _KEEPER.methods_by_name['DownloadObject']._serialized_options = b'\202\343\n\026\212\343\n\022keeper:object:read\352\342\n\014\365\342\n\000\000HB\370\342\n\364\003\202\323\344\223\002\025\022\023/objects/{key}/data'
  _KEEPER.methods_by_name['StartMultipartUpload']._options = None
  _KEEPER.methods_by_name['StartMultipartUpload']._serialized_options = b'\202\343\n\027\212\343\n\023keeper:object:write\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\002\n\"\010/uploads'
  _KEEPER.methods_by_name['UploadPart']._options = None
  _KEEPER.methods_by_name['UploadPart']._serialized_options = b'\202\343\n\027\212\343\n\023keeper:object:write\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\002\034\"\032/objects/{object_id}/parts'
  _KEEPER.methods_by_name['CompleteMultipartUpload']._options = None
  _KEEPER.methods_by_name['CompleteMultipartUpload']._serialized_options = b'\202\343\n\027\212\343\n\023keeper:object:write\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\002\037\"\035/objects/{object_id}/complete'
  _CREATEOBJECTINPUT._serialized_start=144
  _CREATEOBJECTINPUT._serialized_end=177
  _CREATEOBJECTOUTPUT._serialized_start=179
  _CREATEOBJECTOUTPUT._serialized_end=262
  _DESCRIBEOBJECTINPUT._serialized_start=264
  _DESCRIBEOBJECTINPUT._serialized_end=298
  _DESCRIBEOBJECTOUTPUT._serialized_start=300
  _DESCRIBEOBJECTOUTPUT._serialized_end=336
  _DOWNLOADOBJECTINPUT._serialized_start=338
  _DOWNLOADOBJECTINPUT._serialized_end=402
  _DOWNLOADOBJECTOUTPUT._serialized_start=404
  _DOWNLOADOBJECTOUTPUT._serialized_end=454
  _STARTMULTIPARTUPLOADINPUT._serialized_start=456
  _STARTMULTIPARTUPLOADINPUT._serialized_end=483
  _STARTMULTIPARTUPLOADOUTPUT._serialized_start=485
  _STARTMULTIPARTUPLOADOUTPUT._serialized_end=551
  _UPLOADPARTINPUT._serialized_start=553
  _UPLOADPARTINPUT._serialized_end=643
  _UPLOADPARTOUTPUT._serialized_start=645
  _UPLOADPARTOUTPUT._serialized_end=677
  _COMPLETEMULTIPARTUPLOADINPUT._serialized_start=680
  _COMPLETEMULTIPARTUPLOADINPUT._serialized_end=874
  _COMPLETEMULTIPARTUPLOADINPUT_PART._serialized_start=815
  _COMPLETEMULTIPARTUPLOADINPUT_PART._serialized_end=874
  _COMPLETEMULTIPARTUPLOADOUTPUT._serialized_start=876
  _COMPLETEMULTIPARTUPLOADOUTPUT._serialized_end=907
  _KEEPER._serialized_start=910
  _KEEPER._serialized_end=1914
# @@protoc_insertion_point(module_scope)
